LabelStore

Struct LabelStore 

pub struct LabelStore { /* private fields */ }
A store for managing labels associated with Bitcoin addresses, transactions, and outpoints.

Implementations

Source

impl LabelStore

pub fn new() -> Self

Creates a new, empty LabelStore.

pub fn from_file(config: Config) -> Self

Creates a LabelStore from a file specified in the given configuration.

Parameters
  • config: The configuration containing the path to the labels file.
pub fn enable_persist(self, persist: bool) -> Self

Allow to disable persistance of data, useful for tests

pub fn persist(&self)

Persists the current labels to the file specified in the configuration.

pub fn get(&self, key: &LabelKey) -> Option<String>

Retrieves the label associated with the given key.

Parameters
  • key: The key for which to retrieve the label.
Returns

An Option<String> containing the label if found, or None if not.

pub fn edit(&mut self, key: LabelKey, value: Option<String>)

Edits the label associated with the given key.

If a value is provided, it updates the label. If None is provided, it removes the label.

Parameters
  • key: The key for the label to edit.
  • value: An optional new value for the label.
pub fn remove(&mut self, key: LabelKey)

Removes the label associated with the given key.

Parameters
  • key: The key for the label to remove.
pub fn address(&self, address: Address) -> Option<String>

Retrieves the label associated with the given Bitcoin address.

Parameters
  • address: The Bitcoin address for which to retrieve the label.
Returns

An Option<String> containing the label if found, or None if not.

pub fn outpoint(&self, outpoint: OutPoint) -> Option<String>

Retrieves the label associated with the given outpoint.

Parameters
  • outpoint: The outpoint for which to retrieve the label.
Returns

An Option<String> containing the label if found, or None if not.

pub fn transaction(&self, txid: Txid) -> Option<String>

Retrieves the label associated with the given transaction ID.

Parameters
  • txid: The transaction ID for which to retrieve the label.
Returns

An Option<String> containing the label if found, or None if not.