OXpriv

Struct OXpriv 

pub struct OXpriv {
    pub origin: (Fingerprint, DerivationPath),
    pub xkey: Xpriv,
}
A struct that represents an extended private key.

This struct contains the origin fingerprint and derivation path associated with the extended private key, as well as the key itself.

Fields

  • origin - A tuple containing the fingerprint and derivation path.
  • xkey - The extended private key.

Fields

origin: (Fingerprint, DerivationPath)xkey: Xpriv