pub struct LabelStore { /* private fields */ }Expand description
A store for managing labels associated with Bitcoin addresses, transactions, and outpoints.
Implementations
Sourceimpl LabelStore
impl LabelStore
Sourcepub fn from_file(config: Config) -> Self
pub fn from_file(config: Config) -> Self
Creates a LabelStore from a file specified in the given configuration.
Parameters
config: The configuration containing the path to the labels file.
Sourcepub fn enable_persist(self, persist: bool) -> Self
pub fn enable_persist(self, persist: bool) -> Self
Allow to disable persistance of data, useful for tests
Sourcepub fn edit(&mut self, key: LabelKey, value: Option<String>)
pub fn edit(&mut self, key: LabelKey, value: Option<String>)
Edits the label associated with the given key.
If a value is provided, it updates the label. If None is provided, it removes the label.
Parameters
key: The key for the label to edit.value: An optional new value for the label.