pub struct OXpriv {
pub origin: (Fingerprint, DerivationPath),
pub xkey: Xpriv,
}Expand description
A struct that represents an extended private key.
This struct contains the origin fingerprint and derivation path associated with the extended private key, as well as the key itself.
Fields
origin- A tuple containing the fingerprint and derivation path.xkey- The extended private key.
Fields
origin: (Fingerprint, DerivationPath)xkey: XprivAuto Trait Implementations
impl Freeze for OXpriv
impl RefUnwindSafe for OXpriv
impl Send for OXpriv
impl Sync for OXpriv
impl Unpin for OXpriv
impl UnsafeUnpin for OXpriv
impl UnwindSafe for OXpriv